import Vue from 'vue'
import Router from 'vue-router'
import Layout from '../layout/index'

Vue.use(Router)

export const constantRouterMap = [
  { path: '/login',
    meta: { title: '登录', noCache: true },
    component: () => import('@/views/login'),
    hidden: true
  },
  {
    path: '/404',
    component: () => import('@/views/features/404'),
    hidden: true
  },
  {
    path: '/401',
    component: () => import('@/views/features/401'),
    hidden: true
  },
  {
    path: '/redirect',
    component: Layout,
    hidden: true,
    children: [
      {
        path: '/redirect/:path*',
        component: () => import('@/views/features/redirect')
      }
    ]
  },
  {
    path: '/user',
    component: Layout,
    hidden: true,
    redirect: 'noredirect',
    children: [
      {
        path: 'center',
        component: () => import('@/views/system/user/center'),
        name: '个人中心',
        meta: { title: '个人中心' }
      }
    ]
  }
]

export const asyncRouterMap = [
  {
    path: '/',
    component: Layout,
    redirect: '/dashboard',
    meta: { roles: ['root', 'platform_manager'] },
    children: [
      {
        path: 'dashboard',
        component: () => import('@/views/home'),
        name: 'Dashboard',
        meta: { title: '数据总览', icon: 'index' }
      }
    ]
  },
  {
    path: '/',
    component: Layout,
    redirect: '/dashboard',
    meta: { roles: ['store_manager'] },
    children: [
      {
        path: 'dashboard',
        component: () => import('@/views/store/home'),
        name: 'Home',
        meta: { title: '商户首页', icon: 'index' }
      }
    ]
  },
  {
    path: '/stores',
    component: Layout,
    meta: { roles: ['root', 'platform_manager'] },
    children: [
      {
        path: 'manage',
        component: () => import('@/views/store/manage'),
        name: 'store_manage',
        meta: { title: '商户管理', icon: 'mall' }
      }
    ]
  },
  {
    path: '/store',
    component: Layout,
    meta: { roles: ['root', 'platform_manager', 'store_manager'] },
    children: [
      {
        path: 'product',
        component: () => import('@/views/store/product'),
        name: 'product_list',
        meta: { title: '商品列表', icon: 'product' }
      }
    ]
  },
  {
    path: '/order',
    component: Layout,
    meta: { roles: ['root', 'platform_manager'] },
    children: [
      {
        path: 'list',
        component: () => import('@/views/order'),
        name: 'order_list',
        meta: { title: '订单列表', icon: 'order' }
      }
    ]
  },
  {
    path: '/notice',
    component: Layout,
    meta: { roles: ['root', 'platform_manager'] },
    children: [
      {
        path: 'notice_list',
        component: () => import('@/views/notice/index.vue'),
        name: 'notice_list',
        meta: { title: '公告管理', icon: 'notice' }
      }
    ]
  },
  {
    path: '/topic',
    component: Layout,
    meta: { roles: ['root', 'platform_manager', 'store_manager'] },
    children: [
      {
        path: 'topic_list',
        component: () => import('@/views/topic/store/index.vue'),
        name: 'topic_list',
        meta: { title: '动态管理', icon: 'topic' }
      }
    ]
  },
  {
    path: '/activity',
    component: Layout,
    meta: { roles: ['root', 'platform_manager'] },
    children: [
      {
        path: 'activity_list',
        component: () => import('@/views/activity/index.vue'),
        name: 'activity_list',
        meta: { title: '活动管理', icon: 'activity' }
      }
    ]
  },
  {
    path: '/train',
    component: Layout,
    meta: { roles: ['root', 'platform_manager'] },
    children: [
      {
        path: 'list',
        component: () => import('@/views/train'),
        name: 'train_list',
        meta: { title: '培训管理', icon: 'course' }
      }
    ]
  },
  {
    path: '/trainSource',
    component: Layout,
    meta: { roles: ['root', 'platform_manager'] },
    children: [
      {
        path: 'detail',
        component: () => import('@/views/train/detail.vue'),
        name: 'train_detail',
        meta: { title: '培训课程', icon: 'course' }
      }
    ],
    hidden: true
  },
  {
    path: '/marketing',
    component: Layout,
    meta: { roles: ['root', 'platform_manager'] },
    children: [
      {
        path: 'list',
        component: () => import('@/views/marketing'),
        name: 'marketing_list',
        meta: { title: '活动商品', icon: 'marketing' }
      },
      {
        path: 'goods-list',
        component: () => import('@/views/marketing/goods'),
        name: 'goods_list',
        meta: { title: '活动商品', icon: 'course' },
        hidden: true
      }
    ]
  },
  {
    path: '/banner',
    component: Layout,
    meta: { roles: ['root', 'platform_manager'] },
    children: [
      {
        path: 'list',
        component: () => import('@/views/banner'),
        name: 'banner_list',
        meta: { title: '轮播管理', icon: 'banner' }
      }
    ]
  },
  {
    path: '/theme',
    component: Layout,
    meta: { roles: ['root', 'platform_manager'] },
    children: [
      {
        path: 'theme_list',
        component: () => import('@/views/theme/index.vue'),
        name: 'theme_list',
        meta: { title: '主题管理', icon: 'themes' }
      }
    ]
  },
  {
    path: '/vms',
    component: Layout,
    meta: { roles: ['root', 'platform_manager'] },
    children: [
      {
        path: 'vms_list',
        component: () => import('@/views/vms/index.vue'),
        name: 'vms_list',
        meta: { title: '会员管理', icon: 'vip' }
      }
    ]
  },
  {
    path: '/tag',
    component: Layout,
    meta: { roles: ['root', 'platform_manager'] },
    children: [
      {
        path: 'tag_list',
        component: () => import('@/views/tag/index.vue'),
        name: 'tag_list',
        meta: { title: '标签管理', icon: 'tag' }
      }
    ]
  },
  {
    path: '/search',
    component: Layout,
    meta: { roles: ['root', 'platform_manager'] },
    children: [
      {
        path: 'hot_search',
        component: () => import('@/views/search/index.vue'),
        name: 'hot_search',
        meta: { title: '热搜管理', icon: 'hot-search' }
      }
    ]
  }
]

export default new Router({
  // mode: 'history',
  scrollBehavior: () => ({ y: 0 }),
  routes: constantRouterMap
})
